@@ -33,9 +33,10 @@
 #  define KJSEMBED_DEPRECATED_NO_EXPORT KJSEMBED_NO_EXPORT KJSEMBED_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KJSEMBED_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KJSEMBED_NO_DEPRECATED
+#    define KJSEMBED_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
